@@ -20,7 +20,7 @@ document.getElementById("Contents").innerHTML='\
     <li><input type="checkbox" id="070202"><label for="070202">函数、语句及运算符</label><ul>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03010000.html">屏幕 I/O 函数</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03020000.html">文件 I/O 函数</a></li>\
-    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030000.html">日期和时间函数</a></li>\
+    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030000.html">日期与时间函数</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03050000.html">错误处理函数</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03060000.html">逻辑运算符</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03070000.html">数学运算符</a></li>\
@@ -30,10 +30,10 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03040000.html">Basic 中的常量</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03110000.html">比较运算符</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03120000.html">字符串</a></li>\
-    <li><a target="_top" href="zh-CN/text/sbasic/shared/special_vba_func.html">Exclusive VBA functions</a></li>\
+    <li><a target="_top" href="zh-CN/text/sbasic/shared/special_vba_func.html">独家 VBA 函数</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03130000.html">其他命令</a></li>\
 			</ul></li>\
-    <li><input type="checkbox" id="070201"><label for="070201">函数、语句及运算符列表（字母顺序）</label><ul>\
+    <li><input type="checkbox" id="070201"><label for="070201">函数、语句及运算符列表 (字母顺序)</label><ul>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03080601.html">Abs 函数</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03060100.html">AND 运算符</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03104200.html">Array 函数</a></li>\
@@ -302,7 +302,7 @@ document.getElementById("Contents").innerHTML='\
     <li><input type="checkbox" id="0801"><label for="0801">常规信息及用户界面用法</label><ul>\
     <li><a target="_top" href="zh-CN/text/scalc/main0000.html">欢迎使用 LibreOffice Calc 帮助</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/main0503.html">LibreOffice Calc 电子表格的功能</a></li>\
-    <li><a target="_top" href="zh-CN/text/scalc/guide/keyboard.html">快捷键（LibreOffice Calc 辅助功能）</a></li>\
+    <li><a target="_top" href="zh-CN/text/scalc/guide/keyboard.html">快捷键 (LibreOffice Calc 辅助功能)</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/04/01020000.html">电子表格的快捷键</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/05/02140000.html">LibreOffice Calc 中的错误代码</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/01/04060112.html">LibreOffice Calc 中用于编程的加载宏</a></li>\
@@ -334,18 +334,18 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/scalc/main0218.html">工具栏</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/main0201.html">标准工具栏</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/main0212.html">表格数据工具栏</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/main0213.html">窗体导航栏</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/main0213.html">表单导航栏</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/main0214.html">查询设计栏</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/main0226.html">窗体设计工具栏</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/main0226.html">表单设计工具栏</a></li>\
 			</ul></li>\
 		</ul></li>\
-    <li><input type="checkbox" id="0803"><label for="0803">函数（公式）类别及运算符</label><ul>\
+    <li><input type="checkbox" id="0803"><label for="0803">函数 (公式) 类别及运算符</label><ul>\
     <li><a target="_top" href="zh-CN/text/scalc/01/04060000.html">函数向导</a></li>\
-    <li><a target="_top" href="zh-CN/text/scalc/01/04060100.html">函数清单（根据类别）</a></li>\
+    <li><a target="_top" href="zh-CN/text/scalc/01/04060100.html">函数清单 (根据类别)</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/01/04060107.html">矩阵函数</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/01/04060120.html">位操作函数</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/01/04060101.html">数据库函数</a></li>\
-    <li><a target="_top" href="zh-CN/text/scalc/01/04060102.html">日期和时间函数</a></li>\
+    <li><a target="_top" href="zh-CN/text/scalc/01/04060102.html">日期与时间函数</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/01/04060103.html">财务函数第一部分</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/01/04060119.html">财务函数第二部分</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/01/04060118.html">金融函数第三部分</a></li>\
@@ -369,7 +369,7 @@ document.getElementById("Contents").innerHTML='\
     <li><input type="checkbox" id="0804"><label for="0804">载入、保存、导入及导出</label><ul>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/webquery.html">在表格中插入外部数据 (WebQuery)</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/html_doc.html">将工作表以 HTML 格式保存和打开</a></li>\
-    <li><a target="_top" href="zh-CN/text/scalc/guide/csv_formula.html">导入和导出文本文件</a></li>\
+    <li><a target="_top" href="zh-CN/text/scalc/guide/csv_formula.html">导入与导出文本文件</a></li>\
 		</ul></li>\
     <li><input type="checkbox" id="0805"><label for="0805">格式化</label><ul>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/text_rotate.html">旋转文字</a></li>\
@@ -384,7 +384,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/scalc/guide/format_table.html">格式化电子表格</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/format_value.html">格式化带小数的数字</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/value_with_name.html">命名单元格</a></li>\
-    <li><a target="_top" href="zh-CN/text/scalc/guide/table_rotate.html">旋转表格（转置）</a></li>\
+    <li><a target="_top" href="zh-CN/text/scalc/guide/table_rotate.html">旋转表格 (转置)</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/rename_table.html">重命名工作表</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/year2000.html">19xx/20xx 年</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/rounding_numbers.html">使用四舍五入的数字</a></li>\
@@ -396,7 +396,7 @@ document.getElementById("Contents").innerHTML='\
 		</ul></li>\
     <li><input type="checkbox" id="0806"><label for="0806">筛选与排序</label><ul>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/filters.html">应用筛选</a></li>\
-    <li><a target="_top" href="zh-CN/text/scalc/guide/specialfilter.html">筛选：应用高级筛选</a></li>\
+    <li><a target="_top" href="zh-CN/text/scalc/guide/specialfilter.html">筛选: 应用高级筛选</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/autofilter.html">添加自动筛选</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/sorted_list.html">应用排序列表</a></li>\
 		</ul></li>\
@@ -421,12 +421,12 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/scalc/guide/datapilot_updatetable.html">更新数据透视表</a></li>\
 		</ul></li>\
     <li><input type="checkbox" id="08091"><label for="08091">数据透视图</label><ul>\
-    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart.html">Pivot Chart</a></li>\
-    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart_create.html">Creating Pivot Charts</a></li>\
-    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart_edit.html">Editing Pivot Charts</a></li>\
-    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart_filter.html">Filtering Pivot Charts</a></li>\
-    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart_update.html">Pivot Chart Update</a></li>\
-    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart_delete.html">Deleting Pivot Charts</a></li>\
+    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart.html">数据透视图</a></li>\
+    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart_create.html">创建数据透视图</a></li>\
+    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart_edit.html">编辑数据透视图</a></li>\
+    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart_filter.html">筛选数据透视图</a></li>\
+    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart_update.html">数据透视图更新</a></li>\
+    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart_delete.html">删除数据透视图</a></li>\
                 </ul></li>\
     <li><input type="checkbox" id="0810"><label for="0810">方案</label><ul>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/scenario.html">使用方案</a></li>\
@@ -434,7 +434,7 @@ document.getElementById("Contents").innerHTML='\
     <li><input type="checkbox" id="0811"><label for="0811">引用</label><ul>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/relativ_absolut_ref.html">地址和引用，绝对和相对</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/cellreferences.html">引用其他文档中的单元格</a></li>\
-    <li><a target="_top" href="zh-CN/text/scalc/guide/cellreferences_url.html">引用其他工作表和参考 URL</a></li>\
+    <li><a target="_top" href="zh-CN/text/scalc/guide/cellreferences_url.html">引用其他工作表以及引用 URL</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/cellreference_dragdrop.html">通过拖放来引用单元格</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/address_auto.html">将名称识别为地址</a></li>\
 		</ul></li>\
@@ -453,7 +453,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/scalc/guide/formula_enter.html">输入公式</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/formula_value.html">显示公式或数值</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/calculate.html">电子表格中的计算</a></li>\
-    <li><a target="_top" href="zh-CN/text/scalc/guide/calc_date.html">使用日期和时间进行计算</a></li>\
+    <li><a target="_top" href="zh-CN/text/scalc/guide/calc_date.html">使用日期与时间进行计算</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/calc_series.html">自动计算序列</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/calc_timevalues.html">计算时差</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/matrixformula.html">输入矩阵公式</a></li>\
@@ -488,7 +488,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/shared/00/00000005.html">通用词汇表</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/00/00000002.html">Internet 术语词汇表</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/accessibility.html">LibreOffice 中的辅助功能</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/guide/keyboard.html">快捷方式（LibreOffice 辅助功能）</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/guide/keyboard.html">快捷方式 (LibreOffice 辅助功能)</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/04/01010000.html">LibreOffice 中的常规快捷键</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/version_number.html">版本和编译号</a></li>\
 </ul></li>\
@@ -508,7 +508,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/shared/optionen/01010700.html">字体</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/optionen/01010800.html">视图</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/optionen/01010900.html">打印选项</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/optionen/01012000.html">Application Colors</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/optionen/01012000.html">应用程序颜色</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/optionen/01013000.html">辅助功能</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/optionen/java.html">高级</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/optionen/expertconfig.html">专家配置</a></li>\
@@ -570,10 +570,10 @@ document.getElementById("Contents").innerHTML='\
     <li><input type="checkbox" id="10071"><label for="10071">数字签名</label><ul>\
     <li><a target="_top" href="zh-CN/text/shared/guide/digital_signatures.html">关于数字签名</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/digitalsign_send.html">应用数字签名</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/01/digitalsignaturespdf.html">Digital Signature in PDF Export</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/01/signexistingpdf.html">Signing Existing PDF</a></li>\
-    <li><a target="_top" href="zh-CN/text/swriter/01/addsignatureline.html">Adding Signature Line in Text Documents</a></li>\
-    <li><a target="_top" href="zh-CN/text/swriter/01/signsignatureline.html">Signing the Signature Line</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/01/digitalsignaturespdf.html">导出 PDF 的数字签名</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/01/signexistingpdf.html">签署现有的 PDF</a></li>\
+    <li><a target="_top" href="zh-CN/text/swriter/01/addsignatureline.html">在文本文档中添加签名行</a></li>\
+    <li><a target="_top" href="zh-CN/text/swriter/01/signsignatureline.html">签署签名行</a></li>\
                 </ul></li>\
     <li><input type="checkbox" id="1008"><label for="1008">打印，传真，发送</label><ul>\
     <li><a target="_top" href="zh-CN/text/shared/guide/labels_database.html">打印地址标签</a></li>\
@@ -586,13 +586,13 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/swriter/guide/dragdroptext.html">在文档中移动和复制文本</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_table.html">复制电子表格区域至文本文档</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_graphic.html">在文档之间复制图形</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_fromgallery.html">从图片库复制图形</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_fromgallery.html">从图库复制图形</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_beamer.html">拖放数据源视图</a></li>\
 		</ul></li>\
     <li><input type="checkbox" id="1010"><label for="1010">复制与粘贴</label><ul>\
     <li><a target="_top" href="zh-CN/text/shared/guide/copy_drawfunctions.html">将图形对象复制到其他文档中</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_graphic.html">在文档之间复制图形</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_fromgallery.html">从图片库复制图形</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_fromgallery.html">从图库复制图形</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_table.html">复制电子表格区域至文本文档</a></li>\
 		</ul></li>\
     <li><input type="checkbox" id="1012"><label for="1012">图表</label><ul>\
@@ -605,7 +605,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/shared/guide/doc_save.html">保存文档</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/doc_autosave.html">自动保存文档</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/export_ms.html">以其他格式保存文档</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/guide/data_dbase2office.html">以文本格式导入和导出数据</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/guide/data_dbase2office.html">以文本格式导入与导出数据</a></li>\
 		</ul></li>\
     <li><input type="checkbox" id="1014"><label for="1014">链接与引用</label><ul>\
     <li><a target="_top" href="zh-CN/text/shared/guide/hyperlink_insert.html">插入超链接</a></li>\
@@ -627,14 +627,14 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/shared/guide/copytable2application.html">从插入电子表格数据</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/copytext2application.html">插入文本文档数据</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/insert_bitmap.html">插入、编辑和保存位图</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_gallery.html">将图形添加到图片库中</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_gallery.html">将图形添加到图库中</a></li>\
 		</ul></li>\
     <li><input type="checkbox" id="1019"><label for="1019">自动函数</label><ul>\
     <li><a target="_top" href="zh-CN/text/shared/guide/autocorr_url.html">关闭「自动 URL 识别」</a></li>\
 		</ul></li>\
     <li><input type="checkbox" id="1020"><label for="1020">搜索与替换</label><ul>\
-    <li><a target="_top" href="zh-CN/text/shared/guide/data_search2.html">使用窗体筛选器查找</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/guide/data_search.html">查找表格和窗体文档</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/guide/data_search2.html">使用表单筛选器查找</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/guide/data_search.html">查找表格和表单文档</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/01/02100001.html">正则表达式列表</a></li>\
 		</ul></li>\
     <li><input type="checkbox" id="1021"><label for="1021">指南</label><ul>\
@@ -648,7 +648,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/shared/guide/insert_graphic_drawit.html">编辑图形对象</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/line_intext.html">在文本中绘制线条</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/aaa_start.html">第一个步骤</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/guide/gallery_insert.html">从图片库中插入对象</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/guide/gallery_insert.html">从图库中插入对象</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/space_hyphen.html">插入不间断空格、不间断连字符和软连字符</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/insert_specialchar.html">插入特殊字符</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/tabs.html">插入和编辑制表位</a></li>\
@@ -658,7 +658,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/shared/guide/measurement_units.html">选择度量单位</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/language_select.html">选择文档语言</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/data_tabledefine.html">表格设计</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/guide/numbering_stop.html">关闭单独段落的项目符号和编号</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/guide/numbering_stop.html">关闭单独段落的项目符号与编号</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
     <ul><li><input type="checkbox" id="09"><label for="09">数据库功能 (Base)</label><ul>\
@@ -668,10 +668,10 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/shared/guide/data_new.html">创建新数据库</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/data_tables.html">使用表格</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/data_queries.html">使用查询</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/guide/data_forms.html">使用窗体</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/guide/data_forms.html">使用表单</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/data_reports.html">创建报表</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/data_register.html">注册和删除数据库</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/guide/data_im_export.html">导入和导出 Base 中的数据</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/guide/data_im_export.html">导入与导出 Base 中的数据</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/data_enter_sql.html">执行 SQL 命令</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
@@ -684,7 +684,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/simpress/guide/keyboard.html">使用 LibreOffice Impress 中的快捷键</a></li>\
     <li><a target="_top" href="zh-CN/text/sdraw/guide/keyboard.html">绘图对象的快捷键</a></li>\
     <li><a target="_top" href="zh-CN/text/simpress/04/01020000.html">LibreOffice Impress 的快捷键</a></li>\
-    <li><a target="_top" href="zh-CN/text/simpress/04/presenter.html">Presenter Console Keyboard Shortcuts</a></li>\
+    <li><a target="_top" href="zh-CN/text/simpress/04/presenter.html">演讲者控制台快捷键</a></li>\
     <li><a target="_top" href="zh-CN/text/sdraw/04/01020000.html">绘图快捷键</a></li>\
     <li><a target="_top" href="zh-CN/text/simpress/guide/main.html">LibreOffice Impress 使用说明</a></li>\
     <li><a target="_top" href="zh-CN/text/sdraw/guide/main.html">LibreOffice Draw 使用说明</a></li>\
@@ -717,8 +717,8 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/simpress/main0213.html">选项栏</a></li>\
     <li><a target="_top" href="zh-CN/text/simpress/main0214.html">图像栏</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/main0201.html">标准工具栏</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/main0213.html">窗体导航栏</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/main0226.html">窗体设计工具栏</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/main0213.html">表单导航栏</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/main0226.html">表单设计工具栏</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/main0227.html">编辑接点栏</a></li>\
                  </ul></li>\
              </ul></li>\
@@ -740,8 +740,8 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/sdraw/main0210.html">绘图栏</a></li>\
     <li><a target="_top" href="zh-CN/text/sdraw/main0213.html">选项工具栏</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/main0201.html">标准工具栏</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/main0213.html">窗体导航栏</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/main0226.html">窗体设计工具栏</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/main0213.html">表单导航栏</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/main0226.html">表单设计工具栏</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/main0227.html">编辑接点栏</a></li>\
                  </ul></li>\
              </ul></li>\
@@ -764,7 +764,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/sdraw/guide/align_arrange.html">排列，对齐和分布对象</a></li>\
     <li><a target="_top" href="zh-CN/text/simpress/guide/background.html">修改幻灯片背景填充</a></li>\
     <li><a target="_top" href="zh-CN/text/simpress/guide/footer.html">向所有幻灯片添加页眉或页脚</a></li>\
-    <li><a target="_top" href="zh-CN/text/simpress/guide/masterpage.html">Applying a Slide Design to a Master Slide</a></li>\
+    <li><a target="_top" href="zh-CN/text/simpress/guide/masterpage.html">将幻灯片设计应用到幻灯片母版</a></li>\
     <li><a target="_top" href="zh-CN/text/simpress/guide/move_object.html">移动对象</a></li>\
          </ul></li>\
     <li><input type="checkbox" id="0405"><label for="0405">打印</label><ul>\
@@ -814,8 +814,8 @@ document.getElementById("Contents").innerHTML='\
          </ul></li>\
     <li><input type="checkbox" id="0411"><label for="0411">幻灯片播放</label><ul>\
     <li><a target="_top" href="zh-CN/text/simpress/guide/show.html">显示幻灯片放映</a></li>\
-    <li><a target="_top" href="zh-CN/text/simpress/guide/presenter_console.html">Using the Presenter Console</a></li>\
-    <li><a target="_top" href="zh-CN/text/simpress/guide/impress_remote.html">Impress Remote Guide</a></li>\
+    <li><a target="_top" href="zh-CN/text/simpress/guide/presenter_console.html">使用「演讲者控制台」</a></li>\
+    <li><a target="_top" href="zh-CN/text/simpress/guide/impress_remote.html">Impress Remote 指南</a></li>\
     <li><a target="_top" href="zh-CN/text/simpress/guide/individual.html">创建自定义幻灯片放映</a></li>\
     <li><a target="_top" href="zh-CN/text/simpress/guide/rehearse_timings.html">幻灯片更换的排练计时</a></li>\
          </ul></li>\
@@ -825,7 +825,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/smath/main0000.html">欢迎使用 LibreOffice Math 帮助</a></li>\
     <li><a target="_top" href="zh-CN/text/smath/main0503.html">LibreOffice Math 功能</a></li>\
     <li><a target="_top" href="zh-CN/text/smath/guide/main.html">LibreOffice Math 使用说明</a></li>\
-    <li><a target="_top" href="zh-CN/text/smath/guide/keyboard.html">快捷方式（LibreOffice Math 辅助功能）</a></li>\
+    <li><a target="_top" href="zh-CN/text/smath/guide/keyboard.html">快捷方式 (LibreOffice Math 辅助功能)</a></li>\
 		</ul></li>\
     <li><input type="checkbox" id="0302"><label for="0302">命令和菜单项指南</label><ul>\
     <li><a target="_top" href="zh-CN/text/smath/main0100.html">菜单</a></li>\
@@ -848,7 +848,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/swriter/guide/resize_navigator.html">固定窗口和调整窗口大小</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/04/01020000.html">用于 LibreOffice Writer 的快捷键</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/words_count.html">字数统计</a></li>\
-    <li><a target="_top" href="zh-CN/text/swriter/guide/keyboard.html">使用快捷键（LibreOffice Writer 辅助功能）</a></li>\
+    <li><a target="_top" href="zh-CN/text/swriter/guide/keyboard.html">使用快捷键 (LibreOffice Writer 辅助功能)</a></li>\
 		</ul></li>\
     <li><input type="checkbox" id="0202"><label for="0202">命令和菜单项指南</label><ul>\
     <li><input type="checkbox" id="020201"><label for="020201">菜单</label><ul>\
@@ -871,7 +871,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/swriter/main0203.html">图像栏</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/main0204.html">表格栏</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/main0205.html">绘图对象属性栏</a></li>\
-    <li><a target="_top" href="zh-CN/text/swriter/main0206.html">项目符号和编号栏</a></li>\
+    <li><a target="_top" href="zh-CN/text/swriter/main0206.html">项目符号与编号栏</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/main0208.html">状态栏</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/main0210.html">打印预览</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/main0213.html">标尺</a></li>\
@@ -881,9 +881,9 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/swriter/main0220.html">文字对象工具栏</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/main0201.html">标准工具栏</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/main0212.html">表格数据工具栏</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/main0213.html">窗体导航栏</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/main0213.html">表单导航栏</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/main0214.html">查询设计栏</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/main0226.html">窗体设计工具栏</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/main0226.html">表单设计工具栏</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/librelogo/LibreLogo.html">LibreLogo 工具栏</a></li>\
 			</ul></li>\
 		</ul></li>\
@@ -894,7 +894,7 @@ document.getElementById("Contents").innerHTML='\
     <li><input type="checkbox" id="0204"><label for="0204">文本文档中的图形</label><ul>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/insert_graphic.html">插入图形</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/insert_graphic_dialog.html">从文件中插入图形</a></li>\
-    <li><a target="_top" href="zh-CN/text/swriter/guide/insert_graphic_gallery.html">使用拖放功能从图片库插入图形</a></li>\
+    <li><a target="_top" href="zh-CN/text/swriter/guide/insert_graphic_gallery.html">使用拖放功能从图库插入图形</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/insert_graphic_scan.html">插入扫描图像</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/insert_graphic_fromchart.html">将 Calc 图表插入文本文档</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/insert_graphic_fromdraw.html">从 LibreOffice Draw 或 Impress 插入图形</a></li>\
@@ -960,10 +960,10 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/swriter/guide/template_create.html">创建文档模板</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/template_default.html">修改默认模板</a></li>\
 			</ul></li>\
-    <li><a target="_top" href="zh-CN/text/swriter/guide/pageorientation.html">修改页面方向（横向或纵向）</a></li>\
+    <li><a target="_top" href="zh-CN/text/swriter/guide/pageorientation.html">修改页面方向 (横向或纵向)</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/text_capital.html">修改文字的大小写</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/hidden_text.html">隐藏文本</a></li>\
-    <li><a target="_top" href="zh-CN/text/swriter/guide/header_pagestyles.html">定义不同的页眉和页脚</a></li>\
+    <li><a target="_top" href="zh-CN/text/swriter/guide/header_pagestyles.html">定义不同的页眉与页脚</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/header_with_chapter.html">在页眉或页脚中插入章节名称和编号</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/shortcut_writing.html">输入时应用文本格式</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/reset_format.html">重设字体属性</a></li>\
@@ -985,12 +985,12 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/swriter/guide/footer_nextpage.html">插入续页页码</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/footer_pagenumber.html">将页码插入页脚</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/hidden_text.html">隐藏文本</a></li>\
-    <li><a target="_top" href="zh-CN/text/swriter/guide/header_pagestyles.html">定义不同的页眉和页脚</a></li>\
+    <li><a target="_top" href="zh-CN/text/swriter/guide/header_pagestyles.html">定义不同的页眉与页脚</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/header_with_chapter.html">在页眉或页脚中插入章节名称和编号</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/fields_userdata.html">按字段或条件查询用户数据</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/footnote_usage.html">插入和编辑脚注或尾注</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/footnote_with_line.html">脚注之间的间距</a></li>\
-    <li><a target="_top" href="zh-CN/text/swriter/guide/header_footer.html">关于页眉和页脚</a></li>\
+    <li><a target="_top" href="zh-CN/text/swriter/guide/header_footer.html">关于页眉与页脚</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/header_with_line.html">格式化页眉或页脚</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/text_animation.html">使用文本动画</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/form_letters_main.html">创建格式信函</a></li>\
@@ -1051,7 +1051,7 @@ document.getElementById("Contents").innerHTML='\
 	</ul></li></ul>\
     <ul><li><input type="checkbox" id="06"><label for="06">HTML 文档 (Writer Web)</label><ul>\
     <li><a target="_top" href="zh-CN/text/shared/07/09000000.html">网页</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/02/01170700.html">HTML 筛选器和窗体</a></li>\
+    <li><a target="_top" href="zh-CN/text/shared/02/01170700.html">HTML 筛选器和表单</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/send2html.html">以 HTML 格式保存文本文档</a></li>\
 	</ul></li></ul>\
 ';
